@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mixgtk.c :
  * Main functions of the mix gtk front-end
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "2001-05-20 18:03:05 jao"
+ * $Id: mixgtk.c,v 1.14 2002/03/29 16:31:46 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 
 #include "mixgtk_widgets.h"
 #include "mixgtk_cmd_dispatcher.h"
