@@ -27,9 +27,9 @@
 
 #include <gtk/gtk.h>
 
-/* gtk callbacks */
+/* init */
 extern void
-on_colors_activate (GtkWidget *w, gpointer p);
+mixgtk_colorsel_init (void);
 
 
 #endif /* MIXGTK_COLORSEL_H */
