@@ -1,9 +1,9 @@
 /* -*-c-*- ---------------- mixgtk_device.c :
  * actual types for mixgtk devices
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: <2001-05-10 23:42:26 jao>
+ * $Id: mixgtk_device.c,v 1.17 2002/03/29 16:30:49 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,11 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+
 #include <mixlib/mix_vm_command.h>
 #include <mixlib/xmix_device.h>
+
 #include "mixgtk.h"
 #include "mixgtk_gen_handlers.h"
 #include "mixgtk_widgets.h"
