@@ -27,6 +27,7 @@
 
 #include <gtk/gtk.h>
 #include <mixlib/mix_vm.h>
+#include "mixgtk_widgets.h"
 
 /* the possible colorised elements */
 typedef enum {
@@ -43,7 +44,7 @@ typedef enum {
 
 /* initialise the mixal widget */
 extern gboolean
-mixgtk_mixal_init (mix_vm_t *vm);
+mixgtk_mixal_init (mix_vm_t *vm, mixgtk_dialog_id_t top);
 
 /* set the plain, location pointer and break colors */
 extern void
