@@ -32,7 +32,7 @@
 #define REGISTER_NO_ (MIXGTK_WIDGET_rI6 - MIXGTK_WIDGET_rA + 1)
 
 static GtkEntry *reg_entries_[REGISTER_NO_];
-static GtkTooltips *tips_;
+static GtkTooltips *tips_ = NULL;
 static GtkEntry *loc_entry_;
 static GtkWidget *goto_ = NULL;
 static GtkEntry *goto_entry_ = NULL;
@@ -119,7 +119,7 @@ mixgtk_mixvm_init (mix_vm_t *vm, mixgtk_dialog_id_t top)
   g_return_val_if_fail (vm != NULL, FALSE);
   vm_ = vm;
 
-  tips_ = gtk_tooltips_new ();
+  if (!tips_) tips_ = gtk_tooltips_new ();
 
   for (k = 0; k < REGISTER_NO_; ++k)
     {
@@ -235,7 +235,7 @@ void
 mixgtk_mixvm_update_cells_to_address (gint address)
 {
   g_assert (memory_);
-  g_return_if_fail (address < MIX_VM_CELL_NO);
+  if (address >= MIX_VM_CELL_NO) return;
   
   gtk_clist_freeze (memory_);
   gtk_clist_moveto (memory_, address, 0, 0, 0);
