@@ -31,6 +31,9 @@
 /* enumeration of gmixvm dialogs */
 typedef enum {
   MIXGTK_MAIN,	          /* main app window */
+  MIXGTK_MIXVM_DIALOG,    /* mixvm dialog */
+  MIXGTK_MIXAL_DIALOG,	  /* mixal dialog */
+  MIXGTK_DEVICES_DIALOG,  /* devices dialog */
   MIXGTK_WORD_DIALOG,	  /* input dialog for a mix word */
   MIXGTK_ABOUT_DIALOG,
   MIXGTK_GOTO_DIALOG,
@@ -39,7 +42,8 @@ typedef enum {
   MIXGTK_FONTSEL_DIALOG,  /* font selection dialog */
   MIXGTK_DEVFORM_DIALOG,  /* device format config dialog */
   MIXGTK_EXTERNPROG_DIALOG,	/* external programs dialog */
-  MIXGTK_SYMBOLS_DIALOG		/* symbol table dialog */
+  MIXGTK_SYMBOLS_DIALOG,	/* symbol table dialog */
+  MIXGTK_DEVDIR_DIALOG
 } mixgtk_dialog_id_t;
 
 /* enumeration of mixvm widget ids */
@@ -75,7 +79,7 @@ typedef enum {
 
 /* create a new factory from an xml glade file */
 extern gboolean
-mixgtk_widget_factory_init (const char *glade_file);
+mixgtk_widget_factory_init (void);
 
 /* get a dialog */
 extern GtkWidget *
@@ -83,7 +87,7 @@ mixgtk_widget_factory_get_dialog (mixgtk_dialog_id_t dlg);
 
 /* get a widget */
 extern GtkWidget *
-mixgtk_widget_factory_get (mixgtk_widget_id_t widget);
+mixgtk_widget_factory_get (mixgtk_dialog_id_t dlg, mixgtk_widget_id_t widget);
 
 /* Get a widget by name */
 extern GtkWidget *
